@@ -51,7 +51,6 @@ reformat_params = [
     ("excluded_departments", "excludedDepartments"),
     ("excluded_groups", "excludedGroups"),
     ("excluded_users", "excludedUsers"),
-    ("source_ip_groups", "source_ip_groups"),
     ("dest_ip_groups", "destIpGroups"),
     ("dest_ipv6_groups", "destIpv6Groups"),
     ("groups", "groups"),
@@ -62,6 +61,9 @@ reformat_params = [
     ("location_groups", "locationGroups"),
     ("nw_application_groups", "nwApplicationGroups"),
     ("nw_service_groups", "nwServiceGroups"),
+    ("nw_services", "nwServices"),
+    ("source_ip_groups", "source_ip_groups"),
+    ("source_ip_groups", "sourceIpGroups"),
     ("src_ip_groups", "srcIpGroups"),
     ("src_ipv6_groups", "srcIpv6Groups"),
     ("proxy_gateway", "proxyGateway"),
@@ -717,69 +719,144 @@ def format_url(base_string):
     """
     return "".join([line.strip() for line in base_string.splitlines()])
 
+# def zcc_param_mapper(func):
+#     @wraps(func)
+#     def wrapper(self, *args, **kwargs):
+#         query_params = kwargs.get("query_params", {}) or {}
+#         body = kwargs.copy()
+#         mapped_params = {}
+
+#         # -------------------------------
+#         # Detect source of raw inputs
+#         # -------------------------------
+#         raw_os = (
+#             query_params.get("os_type") or
+#             query_params.get("os_types") or
+#             body.get("os_type") or
+#             body.get("os_types")
+#         )
+
+#         if raw_os:
+#             raw_os = [raw_os] if isinstance(raw_os, str) else raw_os
+#             mapped = [
+#                 str(zcc_param_map["os"].get(os.lower()))
+#                 for os in raw_os
+#                 if zcc_param_map["os"].get(os.lower())
+#             ]
+#             if not mapped:
+#                 raise ValueError("Invalid `os_type` or `os_types` provided.")
+#             mapped_params["osTypes"] = ",".join(mapped)
+
+#         raw_reg = (
+#             query_params.get("registration_type") or
+#             query_params.get("registration_types") or
+#             body.get("registration_type") or
+#             body.get("registration_types")
+#         )
+
+#         if raw_reg:
+#             raw_reg = [raw_reg] if isinstance(raw_reg, str) else raw_reg
+#             mapped = [
+#                 str(zcc_param_map["reg_type"].get(rt.lower()))
+#                 for rt in raw_reg
+#                 if zcc_param_map["reg_type"].get(rt.lower())
+#             ]
+#             if not mapped:
+#                 raise ValueError("Invalid `registration_type(s)` provided.")
+#             mapped_params["registrationTypes"] = ",".join(mapped)
+
+#         # Clean aliases
+#         for key in [
+#             "os_type", "os_types",
+#             "registration_type", "registration_types",
+#         ]:
+#             query_params.pop(key, None)
+#             kwargs.pop(key, None)
+
+#         # Distribute to the appropriate location
+#         if "query_params" in kwargs:
+#             query_params.update(mapped_params)
+#             kwargs["query_params"] = query_params
+#         else:
+#             kwargs.update(mapped_params)
+
+#         return func(self, *args, **kwargs)
+
+#     return wrapper
+
 def zcc_param_mapper(func):
     @wraps(func)
     def wrapper(self, *args, **kwargs):
         query_params = kwargs.get("query_params", {}) or {}
+        body = kwargs.copy()
         mapped_params = {}
 
-        # Normalize and map os_types
-        if "os_type" in query_params:
-            os_raw = query_params["os_type"]
-            if isinstance(os_raw, str):
-                os_raw = [os_raw]  # ✅ support single string value
+        # -------------------------------
+        # Detect source of raw inputs
+        # -------------------------------
+        raw_os = (
+            query_params.get("os_type") or
+            query_params.get("os_types") or
+            body.get("os_type") or
+            body.get("os_types")
+        )
 
+        if raw_os:
+            raw_os = [raw_os] if isinstance(raw_os, str) else raw_os
             mapped = [
-                str(zcc_param_map["os"].get(os_type.lower()))
-                for os_type in os_raw
-                if zcc_param_map["os"].get(os_type.lower())
+                str(zcc_param_map["os"].get(os.lower()))
+                for os in raw_os
+                if zcc_param_map["os"].get(os.lower())
             ]
             if not mapped:
-                raise ValueError("Invalid `os_type` provided.")
-            mapped_params["osType"] = ",".join(mapped)
+                raise ValueError("Invalid `os_type` or `os_types` provided.")
+            # Use singular key if original was singular, plural if original was plural
+            if "os_type" in query_params or "os_type" in body:
+                mapped_params["osType"] = ",".join(mapped)
+            else:
+                mapped_params["osTypes"] = ",".join(mapped)
 
-        # Normalize and map os_types
-        if "device_type" in query_params:
-            os_raw = query_params["device_type"]
-            if isinstance(os_raw, str):
-                os_raw = [os_raw]  # ✅ support single string value
-
-            mapped = [
-                str(zcc_param_map["os"].get(os_type.lower()))
-                for os_type in os_raw
-                if zcc_param_map["os"].get(os_type.lower())
-            ]
-            if not mapped:
-                raise ValueError("Invalid `device_type` provided.")
-            mapped_params["deviceType"] = ",".join(mapped)
-
-        # Normalize and map registration_types
-        if "registration_types" in query_params:
-            reg_raw = query_params["registration_types"]
-            if isinstance(reg_raw, str):
-                reg_raw = [reg_raw]
+        raw_reg = (
+            query_params.get("registration_type") or
+            query_params.get("registration_types") or
+            body.get("registration_type") or
+            body.get("registration_types")
+        )
 
+        if raw_reg:
+            raw_reg = [raw_reg] if isinstance(raw_reg, str) else raw_reg
             mapped = [
                 str(zcc_param_map["reg_type"].get(rt.lower()))
-                for rt in reg_raw
+                for rt in raw_reg
                 if zcc_param_map["reg_type"].get(rt.lower())
             ]
             if not mapped:
-                raise ValueError("Invalid `registration_types` provided.")
-            mapped_params["registrationTypes"] = ",".join(mapped)
+                raise ValueError("Invalid `registration_type(s)` provided.")
+            # Use singular key if original was singular, plural if original was plural
+            if "registration_type" in query_params or "registration_type" in body:
+                mapped_params["registrationType"] = ",".join(mapped)
+            else:
+                mapped_params["registrationTypes"] = ",".join(mapped)
 
-        # Drop user-friendly keys
-        query_params.pop("os_types", None)
-        query_params.pop("registration_types", None)
+        # Clean aliases
+        for key in [
+            "os_type", "os_types",
+            "registration_type", "registration_types",
+        ]:
+            query_params.pop(key, None)
+            kwargs.pop(key, None)
 
-        # Merge in mapped numeric params
-        query_params.update(mapped_params)
-        kwargs["query_params"] = query_params
+        # Distribute to the appropriate location
+        if "query_params" in kwargs:
+            query_params.update(mapped_params)
+            kwargs["query_params"] = query_params
+        else:
+            kwargs.update(mapped_params)
 
         return func(self, *args, **kwargs)
+
     return wrapper
 
-# Maps ZCC numeric os_type and registration_type arguments to a human-readable string
 zcc_param_map = {
     "os": {
         "ios": 1,
@@ -798,6 +875,13 @@ zcc_param_map = {
     },
 }
 
+class RateLimitExceededError(Exception):
+    def __init__(self, retry_at: datetime):
+        super().__init__(
+            f"/downloadDevices daily limit reached. Try again at {retry_at.isoformat()}."
+        )
+        self.retry_at = retry_at
+
 
 def dump_request(logger, url: str, method: str, json, params, headers, request_uuid: str, body=True):
     request_headers_filtered = {key: value for key, value in headers.items() if key != "Authorization"}
@@ -861,3 +945,4 @@ def dump_response(
         log_lines.append(f"\n{response_body}")
     log_lines.append("-" * 68)
     logger.info("\n".join(log_lines))
+
