@@ -16,7 +16,7 @@ OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
-from zscaler.zpa.models.application_segment_inspection import ApplicationSegmentInspection
+from zscaler.zpa.models.application_segment import ApplicationSegments
 from zscaler.zpa.app_segment_by_type import ApplicationSegmentByTypeAPI
 from zscaler.utils import add_id_groups, format_url
 
@@ -41,17 +41,29 @@ class AppSegmentsInspectionAPI(APIClient):
         """
         Returns all configured application segment inspection with pagination support.
 
-        Keyword Args:
-            max_items (int): The maximum number of items to request before stopping iteration.
-            max_pages (int): The maximum number of pages to request before stopping iteration.
-            pagesize (int): Specifies the page size. The default size is 20, but the maximum size is 500.
-            search (str, optional): The search string used to match against features and fields.
+        Args:
+            query_params {dict}: Map of query parameters for the request.
+
+                ``[query_params.page]`` {str}: Specifies the page number.
+
+                ``[query_params.page_size]`` {str}: Specifies the page size.
+                    If not provided, the default page size is 20. The max page size is 500.
+
+                ``[query_params.search]`` {str}: Search string for filtering results.
+                ``[query_params.microtenant_id]`` {str}: The unique identifier of the microtenant of ZPA tenant.
 
         Returns:
-            tuple: A tuple containing a list of `AppSegmentsInspection` instances, response object, and error if any.
-        Examples:
-            >>> app_segments = zpa.app_segments_inspection.list_segments_inspection()
+            tuple: A tuple containing (list of ApplicationSegments instances, Response, error)
 
+        Examples:
+            >>> segment_list, _, err = client.zpa.app_segments_inspection.list_segment_inspection(
+            ... query_params={'search': 'AppSegment01', 'page': '1', 'page_size': '100'})
+            ... if err:
+            ...     print(f"Error listing inspection application segment: {err}")
+            ...     return
+            ... print(f"Total application segment inspectiion found: {len(segment_list)}")
+            ... for app in segments:
+            ...     print(app.as_dict())
         """
         http_method = "get".upper()
         api_url = format_url(
@@ -68,14 +80,14 @@ class AppSegmentsInspectionAPI(APIClient):
         if error:
             return (None, None, error)
 
-        response, error = self._request_executor.execute(request, ApplicationSegmentInspection)
+        response, error = self._request_executor.execute(request, ApplicationSegments)
         if error:
             return (None, response, error)
 
         try:
             result = []
             for item in response.get_results():
-                result.append(ApplicationSegmentInspection(self.form_response_body(item)))
+                result.append(ApplicationSegments(self.form_response_body(item)))
         except Exception as error:
             return (None, response, error)
         return (result, response, None)
@@ -89,11 +101,14 @@ class AppSegmentsInspectionAPI(APIClient):
                 The unique identifier for the AppProtection application segment.
 
         Returns:
-            :obj:`tuple`: The AppProtection application segment resource record.
+            :obj:`Tuple`: A tuple containing (ApplicationSegment, Response, error)
 
         Examples:
-            >>> app_segment = zpa.app_segments_inspection.details('99999')
-
+            >>> fetched_segment, _, err = client.zpa.app_segments_inspection.get_segment_inspection('999999')
+            ... if err:
+            ...     print(f"Error fetching segment by ID: {err}")
+            ...     return
+            ... print(f"Fetched segment by ID: {fetched_segment.as_dict()}")
         """
         http_method = "get".upper()
         api_url = format_url(
@@ -109,12 +124,12 @@ class AppSegmentsInspectionAPI(APIClient):
         if error:
             return (None, None, error)
 
-        response, error = self._request_executor.execute(request, ApplicationSegmentInspection)
+        response, error = self._request_executor.execute(request, ApplicationSegments)
         if error:
             return (None, response, error)
 
         try:
-            result = ApplicationSegmentInspection(self.form_response_body(response.get_body()))
+            result = ApplicationSegments(self.form_response_body(response.get_body()))
         except Exception as error:
             return (None, response, error)
         return (result, response, None)
@@ -140,10 +155,6 @@ class AppSegmentsInspectionAPI(APIClient):
                 The type of bypass for the Application Segment. Accepted values are `ALWAYS`, `NEVER` and `ON_NET`.
             config_space (str):
                 The config space for this Application Segment. Accepted values are `DEFAULT` and `SIEM`.
-            default_idle_timeout (int):
-                The Default Idle Timeout for the Application Segment.
-            default_max_age (int):
-                The Default Max Age for the Application Segment.
             description (str):
                 Additional information about this Application Segment.
             double_encrypt (bool):
@@ -171,6 +182,7 @@ class AppSegmentsInspectionAPI(APIClient):
                 - **enabled** (bool): Whether the application is enabled.
                 - **domain** (str): The domain name of the application.
                 - **name** (str): The name of the application.
+                - **app_types** (list[str]): The types of applications is optional (i.e., INSPECT)
 
         Returns:
             :obj:`tuple`: The newly created application segment resource record.
@@ -179,7 +191,7 @@ class AppSegmentsInspectionAPI(APIClient):
 
            Create an application segment using **new TCP port format** (`tcp_port_range`):
 
-            >>> added_segment, _, err = client.zpa.app_segments_pra.add_segment_pra(
+            >>> added_segment, _, err = client.zpa.app_segments_inspection.add_segment_inspection(
             ...     name=f"NewInspectionSegment_{random.randint(1000, 10000)}",
             ...     description=f"NewInspectionSegment_{random.randint(1000, 10000)}",
             ...     enabled=True,
@@ -214,14 +226,20 @@ class AppSegmentsInspectionAPI(APIClient):
         """
         )
 
-        # Construct the body from kwargs (as a dictionary)
         body = kwargs
 
+        # --- Prevent mixed legacy + structured port range usage ---
+        if "tcp_port_ranges" in body and "tcp_port_range" in body:
+            return None, None, ValueError("Cannot use both 'tcp_port_ranges' and 'tcp_port_range' in the same request.")
+
+        if "udp_port_ranges" in body and "udp_port_range" in body:
+            return None, None, ValueError("Cannot use both 'udp_port_ranges' and 'udp_port_range' in the same request.")
+
         # Reformat server_group_ids to match the expected API format (serverGroups)
         if "server_group_ids" in body:
             body["serverGroups"] = [{"id": group_id} for group_id in body.pop("server_group_ids")]
 
-        # Auto-add `"app_types": ["SECURE_REMOTE_ACCESS"]` if missing
+        # Auto-add `"app_types": ["INSPECT"]` if missing
         common_apps_dto = kwargs.get("common_apps_dto")
         if common_apps_dto and "apps_config" in common_apps_dto:
             for app_config in common_apps_dto["apps_config"]:
@@ -254,12 +272,12 @@ class AppSegmentsInspectionAPI(APIClient):
             return (None, None, error)
 
         # Execute the request
-        response, error = self._request_executor.execute(request, ApplicationSegmentInspection)
+        response, error = self._request_executor.execute(request, ApplicationSegments)
         if error:
             return (None, response, error)
 
         try:
-            result = ApplicationSegmentInspection(self.form_response_body(response.get_body()))
+            result = ApplicationSegments(self.form_response_body(response.get_body()))
         except Exception as error:
             return (None, response, error)
         return (result, response, None)
@@ -277,10 +295,6 @@ class AppSegmentsInspectionAPI(APIClient):
         Keyword Args:
             bypass_type (str): Bypass type for the segment. Values: `ALWAYS`, `NEVER`, `ON_NET`.
             config_space (str): Config space for the segment. Values: `DEFAULT`, `SIEM`.
-            default_idle_timeout (int):
-                The Default Idle Timeout for the AppProtection Application Segment.
-            default_max_age (int):
-                The Default Max Age for the AppProtection Application Segment.
             description (str):
                 Additional information about this AppProtection Application Segment.
             domain_names (:obj:`list` of :obj:`str`):
@@ -322,6 +336,7 @@ class AppSegmentsInspectionAPI(APIClient):
                 - **enabled** (bool): Whether the application is enabled.
                 - **domain** (str): The domain name of the application.
                 - **name** (str): The name of the application.
+                - **app_types** (list[str]): The types of applications is optional (i.e., INSPECT).
 
         Returns:
             :obj:`tuple`: The updated AppProtection application segment resource record.
@@ -367,80 +382,87 @@ class AppSegmentsInspectionAPI(APIClient):
         """
         )
 
-        # Construct the body from kwargs (as a dictionary)
         body = kwargs
 
-        # Reformat server_group_ids to match the expected API format (serverGroups)
-        if "server_group_ids" in body:
-            body["serverGroups"] = [{"id": group_id} for group_id in body.pop("server_group_ids")]
+        if "tcp_port_ranges" in body and "tcp_port_range" in body:
+            return None, None, ValueError("Cannot use both 'tcp_port_ranges' and 'tcp_port_range'.")
+        if "udp_port_ranges" in body and "udp_port_range" in body:
+            return None, None, ValueError("Cannot use both 'udp_port_ranges' and 'udp_port_range'.")
 
-        # Ensure `app_types` is set in `commonAppsDto.apps_config`
+        microtenant_id = body.get("microtenant_id", None)
+        params = {"microtenantId": microtenant_id} if microtenant_id else {}
+
+        if "server_group_ids" in body:
+            body["serverGroups"] = [{"id": gid} for gid in body.pop("server_group_ids")]
+
+        # Auto-add `"app_types": ["INSPECT"]` if missing
         common_apps_dto = kwargs.get("common_apps_dto")
         if common_apps_dto and "apps_config" in common_apps_dto:
             for app_config in common_apps_dto["apps_config"]:
-                if "app_types" not in app_config:  # Only set if missing
+                if "app_types" not in app_config:  # Only add if missing
                     app_config["app_types"] = ["INSPECT"]
 
-            body["commonAppsDto"] = common_apps_dto  # Update the request payload
-
-        # Fetch Secure Remote Access apps (same logic as before)
+        common_apps_dto = kwargs.get("common_apps_dto")
         if common_apps_dto and "apps_config" in common_apps_dto:
             app_segment_api = ApplicationSegmentByTypeAPI(self._request_executor, self.config)
 
-            # Fetch all INSPECT apps (no filtering, so we get everything)
-            segments_list, _, err = app_segment_api.get_segments_by_type(application_type="INSPECT", query_params={})
+            segments_list, _, err = app_segment_api.get_segments_by_type(
+                application_type="INSPECT",
+                query_params={"microtenant_id": microtenant_id} if microtenant_id else {}
+            )
 
             if err:
-                return (None, None, f"Error fetching application segment data: {err}")
+                return None, None, f"Error fetching INSPECT segments: {err}"
 
-            # Step 2: Find the correct entry where `appId == segment_id`
-            matched_segment = next((app for app in segments_list if app.app_id == segment_id), None)
+            # Map: domain -> segment
+            existing_apps = {s.domain: s for s in segments_list if s.app_id == segment_id}
 
-            if not matched_segment:
-                return (None, None, f"Error: No matching Inspetion App found with appId '{segment_id}' in existing segments.")
+            # Assign inspect_app_id and inspect_app_id
+            for app in common_apps_dto["apps_config"]:
+                domain = app.get("domain")
+                app["inspect_app_id"] = segment_id
+                if domain in existing_apps:
+                    app["inspect_app_id"] = existing_apps[domain].id
+                else:
+                    app["inspect_app_id"] = ""  # fallback to empty
 
-            inspect_app_id = matched_segment.id
+            # Compute deleted Inspection apps
+            desired_domains = {a["domain"] for a in common_apps_dto["apps_config"]}
+            deleted_ids = [app.id for domain, app in existing_apps.items() if domain not in desired_domains]
+            if deleted_ids:
+                common_apps_dto["deleted_inspect_apps"] = deleted_ids
 
-            # Step 3: Assign `appId` and `inspectAppId`
-            for app_config in common_apps_dto["apps_config"]:
-                app_config["app_id"] = segment_id  # Auto-assign appId (segment_id)
-                app_config["inspect_app_id"] = inspect_app_id  # Auto-assign inspectAppId
+            body["commonAppsDto"] = common_apps_dto
 
-            body["commonAppsDto"] = common_apps_dto  # Update the request payload
-
-        # Process TCP and UDP port attributes
+        # --- Normalize port ranges ---
         if "tcp_port_ranges" in body:
-            # Use format 1 (tcpPortRanges)
             body["tcpPortRanges"] = body.pop("tcp_port_ranges")
         elif "tcp_port_range" in body:
-            # Use format 2 (tcpPortRange)
             body["tcpPortRange"] = [{"from": pr["from"], "to": pr["to"]} for pr in body.pop("tcp_port_range")]
 
         if "udp_port_ranges" in body:
-            # Use format 1 (udpPortRanges)
             body["udpPortRanges"] = body.pop("udp_port_ranges")
         elif "udp_port_range" in body:
-            # Use format 2 (udpPortRange)
             body["udpPortRange"] = [{"from": pr["from"], "to": pr["to"]} for pr in body.pop("udp_port_range")]
 
-        # Apply add_id_groups to reformat params based on self.reformat_params
         add_id_groups(self.reformat_params, kwargs, body)
 
-        request, error = self._request_executor.create_request(http_method, api_url, body, {})
+        request, error = self._request_executor.create_request(http_method, api_url, body, {}, params)
         if error:
             return (None, None, error)
 
-        response, error = self._request_executor.execute(request, ApplicationSegmentInspection)
+        response, error = self._request_executor.execute(request, ApplicationSegments)
         if error:
             return (None, response, error)
 
         if response is None:
-            return (ApplicationSegmentInspection({"id": segment_id}), None, None)
+            return (ApplicationSegments({"id": segment_id}), None, None)
 
         try:
-            result = ApplicationSegmentInspection(self.form_response_body(response.get_body()))
+            result = ApplicationSegments(self.form_response_body(response.get_body()))
         except Exception as error:
             return (None, response, error)
+
         return (result, response, None)
 
     def delete_segment_inspection(self, segment_id: str, force_delete: bool = False) -> int:
@@ -464,7 +486,6 @@ class AppSegmentsInspectionAPI(APIClient):
             ...     print(f"Error deleting application segment: {err}")
             ...     return
             ... print(f"application segment with ID {'999999'} deleted successfully.")
-
         """
         http_method = "delete".upper()
         api_url = format_url(
